%%%%%%%%%%%%
% GROWTH.M %
%%%%%%%%%%%%

% Performs empirical work reported in
% "Sample Splitting and Threshold Estimation"

% Written by
% Bruce E. Hansen
% Department of Economics
% Social Science Building
% University of Wisconsin
% Madison, WI 53706-1393
% bhansen@ssc.wisc.edu
% http://www.ssc.wisc.edu/~bhansen/



% Load procedures and data %                 
function growth();
load dur_john.txt;
data=dur_john;

%Latex%
tex = fopen('out.tex','wt');
fprintf(tex,'\\documentclass{article}\n');
fprintf(tex,'\\usepackage{geometry}\n');
fprintf(tex,'\\linespread{1.3}\n');
fprintf(tex,'\\title{Sample splitting and threshold estimation (Empirical Analysis Output)}\n');
fprintf(tex,'\\author{Bruce E. Hansen \\\\ Department of Economics\\\\University of Wisconsin Madison}\n');
fprintf(tex,'\\begin{document}\n');
fprintf(tex,'\\maketitle');
fclose(tex);


% Exclude missing variables and oil states %
srow=[5;6;10;11];
for i=1:length(srow)
    temp_data=zeros(1,length(data(1,:)));
    for j=1:length(data(:,1))
        if 1-(data(j,srow(i))==-999)
            temp_data=[temp_data;data(j,:)];
        end;
    end;
        data=temp_data(2:length(temp_data),:);
end;

temp_data=zeros(1,length(data(1,:)));
for i=1:length(data(:,1))
    if data(i,2)>0
        temp_data=[temp_data;data(i,:)];
    end;
end
data=temp_data(2:length(temp_data),:);

% Make a data transformations %
diff=log(data(:,6))-log(data(:,5));
q=data(:,5);
gdp60=log(q);
iony=log(data(:,9)/100);
pgro=log(data(:,8)/100+.05);
sch=log(data(:,10)/100);
lit=data(:,11);
dat=[diff,gdp60,iony,pgro,sch,q,lit];

% Program switches %
rep=1000;
h=1;
na=['GNP Gwth';'GDP 1960';'Inv/GDP ';'Pop Gwth';'School  ';'GDP 1960';'Literacy']; %The elements must have the same length including blanket %
dum=[2;3;4;5];

disp('Testing for a First Sample Split, Using Output');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\section{Testing for a First Sample Split, Using Output}\n');
fprintf(tex,'\\subsection{Using Output}\n');
fclose(tex);

disp(' ');
thr_het(dat,1,dum,6,.15,1000);
disp(' ');
disp(' ');
disp('Testing for a First Sample Split, Using Literacy Rate ');
tex=fopen('out.tex','a+');
fprintf(tex,'\\subsection{Using Literacy Rate}\n');
fclose(tex);
disp(' ');
thr_het(dat,1,dum,7,0.15,1000);
disp(' ');
disp(' ');
% Estimate First Sample Split, Using Output as Threshold %
qhat1 = thr_est(dat,na,1,dum,6,h);

% Second Level %
i=(q>qhat1);
temp=0;
for ii=1:length(i)
    if i(ii)==1
        if temp==0;
            dati=dat(ii,:);
            temp=1;
        else
            dati=[dati;dat(ii,:)];
        end;
    end;
end;

disp('Sub-Sample, Incomes over 863');
disp('Testing for a Second Sample Split, Using Output');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\section{Sub-Sample, Incomes over 863(Testing for a Second Sample Split)}\n');
fprintf(tex,'\\subsection{Testing for a Second Sample Split,Using Output}\n');
fclose(tex);

disp(' ');
thr_het(dati,1,dum,6,0.15,1000);
disp(' ');
disp(' ');
disp('Testing for a Second Sample Split, Using Literacy Rate ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\subsection{Testing for a Second Sample Split,Using Literacy Rate}\n');
fclose(tex);

disp(' ');
thr_het(dati,1,dum,7,0.15,1000);
disp('Estimate Second Sample Split, Using Literacy Rate as Threshold ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\subsection{Estimate Second Sample Split, Using Literacy Rate as Threshold}\n');
fclose(tex);

qhat2 = thr_est(dati,na,1,dum,7,h);
disp(' ');

% Third Level %
i1=(lit<=qhat2).*i;
i2=(lit>qhat2).*i;
temp=0;
for ii=1:length(i1)
    if i1(ii)==1
        if temp==0;
            dat1=dat(ii,:);
            temp=1;
        else
            dat1=[dat1;dat(ii,:)];
        end;
    end;
end;

temp=0;
for ii=1:length(i2)
    if i2(ii)==1
        if temp==0;
            dat2=dat(ii,:);
            temp=1;
        else
            dat2=[dat2;dat(ii,:)];
        end;
    end;
end;

disp('Sub-Sample, Incomes over 863, Literacy Under 45');
disp('Testing for a Third Sample Split, Using Output');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\section{Sub-Sample, Incomes over 863, Literacy Under 45}\n');
fprintf(tex,'\\subsection{Testing for a Third Sample Split, Using Output}\n');
fclose(tex);

disp(' ');
thr_het(dat1,1,dum,6,0.15,1000);
disp(' ');
disp(' ');
disp('Testing for a Third Sample Split, Using Literacy Rate ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\subsection{Testing for a Third Sample Split, Using Literacy Rate}\n');
fclose(tex);

disp(' ');
thr_het(dat1,1,dum,7,0.15,1000);
disp(' ');
disp(' ');
disp('Sub-Sample, Incomes over 863, Literacy Over 45 ');
disp('Testing for a Third Sample Split, Using Output ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\section{Sub-Sample, Incomes over 863, Literacy Over 45}\n');
fprintf(tex,'\\subsection{Testing for a Third Sample Split, Using Output}\n');
fclose(tex);

disp(' ');
thr_het(dat2,1,dum,6,0.15,1000);
disp(' ');
disp(' ');
disp('Testing for a Third Sample Split, Using Literacy Rate ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\subsection{Testing for a Third Sample Split, Using Literacy Rate}\n');
fclose(tex);

thr_het(dat2,1,dum,7,0.15,1000);
disp(' ');
disp(' ');

%Latex%
tex=fopen('out.tex','a+');
fprintf(tex,'\\end{document}\n');
fclose(tex);




        
    